==> knative-model-5.9.0-sources.jar: io/fabric8/knative/serving/v1/RevisionStatusBuilder.java <==
package io.fabric8.knative.serving.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class RevisionStatusBuilder extends io.fabric8.knative.serving.v1.RevisionStatusFluentImpl<io.fabric8.knative.serving.v1.RevisionStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.knative.serving.v1.RevisionStatus,io.fabric8.knative.serving.v1.RevisionStatusBuilder>{
  public RevisionStatusBuilder() {
    this(false);
  }
  public RevisionStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new RevisionStatus(), validationEnabled);
  }
  public RevisionStatusBuilder(io.fabric8.knative.serving.v1.RevisionStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public RevisionStatusBuilder(io.fabric8.knative.serving.v1.RevisionStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new RevisionStatus(), validationEnabled);
  }
  public RevisionStatusBuilder(io.fabric8.knative.serving.v1.RevisionStatusFluent<?> fluent,io.fabric8.knative.serving.v1.RevisionStatus instance) {
    this(fluent, instance, false);
  }
  public RevisionStatusBuilder(io.fabric8.knative.serving.v1.RevisionStatusFluent<?> fluent,io.fabric8.knative.serving.v1.RevisionStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withActualReplicas(instance.getActualReplicas()); 
    fluent.withAnnotations(instance.getAnnotations()); 
    fluent.withConditions(instance.getConditions()); 
    fluent.withContainerStatuses(instance.getContainerStatuses()); 
    fluent.withDesiredReplicas(instance.getDesiredReplicas()); 
    fluent.withImageDigest(instance.getImageDigest()); 
    fluent.withLogUrl(instance.getLogUrl()); 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withServiceName(instance.getServiceName()); 
    this.validationEnabled = validationEnabled; 
  }
  public RevisionStatusBuilder(io.fabric8.knative.serving.v1.RevisionStatus instance) {
    this(instance,false);
  }
  public RevisionStatusBuilder(io.fabric8.knative.serving.v1.RevisionStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withActualReplicas(instance.getActualReplicas()); 
    this.withAnnotations(instance.getAnnotations()); 
    this.withConditions(instance.getConditions()); 
    this.withContainerStatuses(instance.getContainerStatuses()); 
    this.withDesiredReplicas(instance.getDesiredReplicas()); 
    this.withImageDigest(instance.getImageDigest()); 
    this.withLogUrl(instance.getLogUrl()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withServiceName(instance.getServiceName()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.knative.serving.v1.RevisionStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.knative.serving.v1.RevisionStatus build() {
    RevisionStatus buildable = new RevisionStatus(fluent.getActualReplicas(),fluent.getAnnotations(),fluent.getConditions(),fluent.getContainerStatuses(),fluent.getDesiredReplicas(),fluent.getImageDigest(),fluent.getLogUrl(),fluent.getObservedGeneration(),fluent.getServiceName());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RevisionStatusBuilder that = (RevisionStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> knative-model-6.0.0-sources.jar: io/fabric8/knative/serving/v1/RevisionStatusBuilder.java <==
package io.fabric8.knative.serving.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class RevisionStatusBuilder extends RevisionStatusFluentImpl<RevisionStatusBuilder> implements VisitableBuilder<RevisionStatus,RevisionStatusBuilder>{
  public RevisionStatusBuilder() {
    this(false);
  }
  public RevisionStatusBuilder(Boolean validationEnabled) {
    this(new RevisionStatus(), validationEnabled);
  }
  public RevisionStatusBuilder(RevisionStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public RevisionStatusBuilder(RevisionStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new RevisionStatus(), validationEnabled);
  }
  public RevisionStatusBuilder(RevisionStatusFluent<?> fluent,RevisionStatus instance) {
    this(fluent, instance, false);
  }
  public RevisionStatusBuilder(RevisionStatusFluent<?> fluent,RevisionStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withActualReplicas(instance.getActualReplicas()); 
    fluent.withAnnotations(instance.getAnnotations()); 
    fluent.withConditions(instance.getConditions()); 
    fluent.withContainerStatuses(instance.getContainerStatuses()); 
    fluent.withDesiredReplicas(instance.getDesiredReplicas()); 
    fluent.withImageDigest(instance.getImageDigest()); 
    fluent.withLogUrl(instance.getLogUrl()); 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withServiceName(instance.getServiceName()); 
    this.validationEnabled = validationEnabled; 
  }
  public RevisionStatusBuilder(RevisionStatus instance) {
    this(instance,false);
  }
  public RevisionStatusBuilder(RevisionStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withActualReplicas(instance.getActualReplicas()); 
    this.withAnnotations(instance.getAnnotations()); 
    this.withConditions(instance.getConditions()); 
    this.withContainerStatuses(instance.getContainerStatuses()); 
    this.withDesiredReplicas(instance.getDesiredReplicas()); 
    this.withImageDigest(instance.getImageDigest()); 
    this.withLogUrl(instance.getLogUrl()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withServiceName(instance.getServiceName()); 
    this.validationEnabled = validationEnabled; 
  }
  RevisionStatusFluent<?> fluent;
  Boolean validationEnabled;
  public RevisionStatus build() {
    RevisionStatus buildable = new RevisionStatus(fluent.getActualReplicas(),fluent.getAnnotations(),fluent.getConditions(),fluent.getContainerStatuses(),fluent.getDesiredReplicas(),fluent.getImageDigest(),fluent.getLogUrl(),fluent.getObservedGeneration(),fluent.getServiceName());
    return buildable;
  }
  
}
